Index: lemon/graph_to_eps.h
===================================================================
--- lemon/graph_to_eps.h	(revision 2178)
+++ lemon/graph_to_eps.h	(revision 2207)
@@ -36,5 +36,5 @@
 
 #include<lemon/bits/invalid.h>
-#include<lemon/xy.h>
+#include<lemon/dim2.h>
 #include<lemon/maps.h>
 #include<lemon/color.h>
@@ -82,5 +82,5 @@
   std::ostream& os;
   
-  typedef ConstMap<typename Graph::Node,xy<double> > CoordsMapType;
+  typedef ConstMap<typename Graph::Node,dim2::Point<double> > CoordsMapType;
   CoordsMapType _coords;
   ConstMap<typename Graph::Node,double > _nodeSizes;
@@ -147,5 +147,5 @@
 			  bool _pros=false) :
     g(_g), os(_os),
-    _coords(xy<double>(1,1)), _nodeSizes(.01), _nodeShapes(0),
+    _coords(dim2::Point<double>(1,1)), _nodeSizes(.01), _nodeShapes(0),
     _nodeColors(WHITE), _edgeColors(BLACK),
     _edgeWidths(1.0), _edgeWidthScale(0.003),
@@ -314,5 +314,5 @@
   }
   template<class TT>
-  static std::string psOut(const xy<TT> &p) 
+  static std::string psOut(const dim2::Point<TT> &p) 
     {
       std::ostringstream os;	
@@ -338,5 +338,6 @@
 
   ///Sets the map of the node coordinates.
   ///\param x must be a node map with xy<double> or \ref xy "xy<int>" values. 
   template<class X> GraphToEps<CoordsTraits<X> > coords(const X &x) {
     dontPrint=true;
@@ -670,5 +671,5 @@
 
 protected:
-  bool isInsideNode(xy<double> p, double r,int t) 
+  bool isInsideNode(dim2::Point<double> p, double r,int t) 
   {
     switch(t) {
@@ -737,8 +738,8 @@
     double diag_len = 1;
     if(!(_absoluteNodeSizes&&_absoluteEdgeWidths)) {
-      BoundingBox<double> bb;
+      dim2::BoundingBox<double> bb;
       for(NodeIt n(g);n!=INVALID;++n) bb.add(mycoords[n]);
       if (bb.empty()) {
-	bb = BoundingBox<double>(xy<double>(0,0));
+	bb = dim2::BoundingBox<double>(dim2::Point<double>(0,0));
       }
       diag_len = std::sqrt((bb.bottomLeft()-bb.topRight()).normSquare());
@@ -748,8 +749,8 @@
     }
     
-    BoundingBox<double> bb;
+    dim2::BoundingBox<double> bb;
     for(NodeIt n(g);n!=INVALID;++n) {
       double ns=_nodeSizes[n]*_nodeScale;
-      xy<double> p(ns,ns);
+      dim2::Point<double> p(ns,ns);
       switch(_nodeShapes[n]) {
       case CIRCLE:
@@ -761,14 +762,14 @@
       case MALE:
 	bb.add(-p+mycoords[n]);
-	bb.add(xy<double>(1.5*ns,1.5*std::sqrt(3.0)*ns)+mycoords[n]);
+	bb.add(dim2::Point<double>(1.5*ns,1.5*std::sqrt(3.0)*ns)+mycoords[n]);
 	break;
       case FEMALE:
 	bb.add(p+mycoords[n]);
-	bb.add(xy<double>(-ns,-3.01*ns)+mycoords[n]);
+	bb.add(dim2::Point<double>(-ns,-3.01*ns)+mycoords[n]);
 	break;
       }
     }
     if (bb.empty()) {
-      bb = BoundingBox<double>(xy<double>(0,0));
+      bb = dim2::BoundingBox<double>(dim2::Point<double>(0,0));
     }
     
@@ -871,5 +872,6 @@
 		  (A4WIDTH-2*A4BORDER)/bb.width());
 	os << ((A4WIDTH -2*A4BORDER)-sc*bb.width())/2 + A4BORDER << ' '
-	   << ((A4HEIGHT-2*A4BORDER)-sc*bb.height())/2 + A4BORDER << " translate\n"
+	   << ((A4HEIGHT-2*A4BORDER)-sc*bb.height())/2 + A4BORDER
+	   << " translate\n"
 	   << sc << " dup scale\n"
 	   << -bb.left() << ' ' << -bb.bottom() << " translate\n";
@@ -880,5 +882,6 @@
 		  (A4WIDTH-2*A4BORDER)/bb.height());
 	os << ((A4WIDTH -2*A4BORDER)-sc*bb.height())/2 + A4BORDER << ' '
-	   << ((A4HEIGHT-2*A4BORDER)-sc*bb.width())/2 + A4BORDER  << " translate\n"
+	   << ((A4HEIGHT-2*A4BORDER)-sc*bb.width())/2 + A4BORDER 
+	   << " translate\n"
 	   << sc << " dup scale\n90 rotate\n"
 	   << -bb.left() << ' ' << -bb.top() << " translate\n";	
@@ -905,33 +908,34 @@
 	  sw-=_parEdgeDist;
 	  sw/=-2.0;
-	  xy<double> dvec(mycoords[g.target(*i)]-mycoords[g.source(*i)]);
+	  dim2::Point<double>
+	    dvec(mycoords[g.target(*i)]-mycoords[g.source(*i)]);
 	  double l=std::sqrt(dvec.normSquare()); 
 	  ///\todo better 'epsilon' would be nice here.
-	  xy<double> d(dvec/std::max(l,EPSILON));
- 	  xy<double> m;
-// 	  m=xy<double>(mycoords[g.target(*i)]+mycoords[g.source(*i)])/2.0;
-
-//  	  m=xy<double>(mycoords[g.source(*i)])+
+	  dim2::Point<double> d(dvec/std::max(l,EPSILON));
+ 	  dim2::Point<double> m;
+// 	  m=dim2::Point<double>(mycoords[g.target(*i)]+mycoords[g.source(*i)])/2.0;
+
+//  	  m=dim2::Point<double>(mycoords[g.source(*i)])+
 // 	    dvec*(double(_nodeSizes[g.source(*i)])/
 // 	       (_nodeSizes[g.source(*i)]+_nodeSizes[g.target(*i)]));
 
- 	  m=xy<double>(mycoords[g.source(*i)])+
+ 	  m=dim2::Point<double>(mycoords[g.source(*i)])+
 	    d*(l+_nodeSizes[g.source(*i)]-_nodeSizes[g.target(*i)])/2.0;
 
 	  for(typename std::vector<Edge>::iterator e=i;e!=j;++e) {
 	    sw+=_edgeWidths[*e]*_edgeWidthScale/2.0;
-	    xy<double> mm=m+rot90(d)*sw/.75;
+	    dim2::Point<double> mm=m+rot90(d)*sw/.75;
 	    if(_drawArrows) {
 	      int node_shape;
-	      xy<double> s=mycoords[g.source(*e)];
-	      xy<double> t=mycoords[g.target(*e)];
+	      dim2::Point<double> s=mycoords[g.source(*e)];
+	      dim2::Point<double> t=mycoords[g.target(*e)];
 	      double rn=_nodeSizes[g.target(*e)]*_nodeScale;
 	      node_shape=_nodeShapes[g.target(*e)];
-	      Bezier3 bez(s,mm,mm,t);
+	      dim2::Bezier3 bez(s,mm,mm,t);
 	      double t1=0,t2=1;
 	      for(int i=0;i<INTERPOL_PREC;++i)
 		if(isInsideNode(bez((t1+t2)/2)-t,rn,node_shape)) t2=(t1+t2)/2;
 		else t1=(t1+t2)/2;
-	      xy<double> apoint=bez((t1+t2)/2);
+	      dim2::Point<double> apoint=bez((t1+t2)/2);
 	      rn = _arrowLength+_edgeWidths[*e]*_edgeWidthScale;
 	      rn*=rn;
@@ -940,5 +944,5 @@
 		if((bez((t1+t2)/2)-apoint).normSquare()>rn) t1=(t1+t2)/2;
 		else t2=(t1+t2)/2;
-	      xy<double> linend=bez((t1+t2)/2);	      
+	      dim2::Point<double> linend=bez((t1+t2)/2);	      
 	      bez=bez.before((t1+t2)/2);
 // 	      rn=_nodeSizes[g.source(*e)]*_nodeScale;
@@ -957,5 +961,5 @@
 		 << bez.p3.x << ' ' << bez.p3.y << ' '
 		 << bez.p4.x << ' ' << bez.p4.y << " curveto stroke\n";
-	      xy<double> dd(rot90(linend-apoint));
+	      dim2::Point<double> dd(rot90(linend-apoint));
 	      dd*=(.5*_edgeWidths[*e]*_edgeWidthScale+_arrowWidth)/
 		std::sqrt(dd.normSquare());
@@ -983,5 +987,5 @@
 	   &&g.source(e)!=g.target(e))
 	  if(_drawArrows) {
-	    xy<double> d(mycoords[g.target(e)]-mycoords[g.source(e)]);
+	    dim2::Point<double> d(mycoords[g.target(e)]-mycoords[g.source(e)]);
 	    double rn=_nodeSizes[g.target(e)]*_nodeScale;
 	    int node_shape=_nodeShapes[g.target(e)];
@@ -338,5 +338,6 @@
 
   ///Sets the map of the node coordinates.
-  ///\param x must be a node map with xy<double> or \ref xy "xy<int>" values. 
+  ///\param x must be a node map with dim2::Point<double> or
+  ///\ref dim2::Point "dim2::Point<int>" values. 
   template<class X> GraphToEps<CoordsTraits<X> > coords(const X &x) {
     dontPrint=true;
